#
# spec file for package libavif
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Also update baselibs.conf if you bump the version
%global lib_soversion 16
%global lib_name libavif%{lib_soversion}
%global libargparse ee74d1b53bd680748af14e737378de57e2a0a954

# currently disabled
%bcond_with     man_pages
%bcond_with     tests

%ifarch aarch64 x86_64
%bcond_without  SvtAv1Enc
%else
%bcond_with     SvtAv1Enc
%endif

Name:           libavif
Version:        1.3.0
Release:        1.2
Summary:        Library for encoding and decoding .avif files
License:        BSD-2-Clause
URL:            https://github.com/AOMediaCodec/libavif
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source10:       https://github.com/kmurray/libargparse/archive/%{libargparse}/libargparse-%{libargparse}.tar.gz
Source99:       baselibs.conf
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(aom) >= 2.0.0
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng) >= 1.6.32
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libyuv)
BuildRequires:  pkgconfig(rav1e) >= 0.5.0
%if %{with SvtAv1Enc}
BuildRequires:  pkgconfig(SvtAv1Enc)
%endif
%if %{with man_pages}
BuildRequires:  pandoc
%endif
%if %{with tests}
BuildRequires:  ImageMagick
BuildRequires:  pkgconfig(gtest)
%endif
%if 0%{?suse_version} < 1600
BuildRequires:  gcc11-PIE
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(libsharpyuv)
%endif

%description
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

%package -n avif-tools
Summary:        Tools for libavif
License:        BSD-2-Clause AND MIT
Provides:       bundled(libargparse) = 20211125.ee74d1b
Provides:       libavif-tools = %{version}
Obsoletes:      libavif-tools < %{version}

%description -n avif-tools
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

This package holds the commandline tools for libavif.

%package -n %{lib_name}
#
Summary:        Shared library from libavif

%description -n %{lib_name}
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

This package holds the shared library for libavif.

%package -n gdk-pixbuf-loader-libavif
Summary:        AVIF image loader for GTK+ applications

%description -n gdk-pixbuf-loader-libavif
A pixbuf-loader plugin to load AVIF images in GTK+ applications.

%package devel
#
Summary:        Development files for libavif
Requires:       %{lib_name} = %{version}

%description devel
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

This package holds the development files for libavif.

%prep
%autosetup -p1

mkdir ext/libargparse
tar -xf %{SOURCE10} --strip-components=1 -C ext/libargparse

%build
%define __builder ninja
%cmake \
%if 0%{?suse_version} < 1600
	-DCMAKE_C_COMPILER=gcc-11	\
	-DCMAKE_CXX_COMPILER=g++-11	\
	-DAVIF_LIBSHARPYUV:BOOL=OFF	\
%else
	-DAVIF_LIBSHARPYUV=SYSTEM	\
%endif
%if %{with SvtAv1Enc}
	-DAVIF_CODEC_SVT=SYSTEM		\
%endif
%if %{with man_pages}
	-DAVIF_BUILD_MAN_PAGES:BOOL=ON	\
%endif
%if %{with tests}
	-DAVIF_BUILD_TESTS:BOOL=ON	\
	-DAVIF_GTEST=SYSTEM		\
%endif
	-DAVIF_CODEC_AOM=SYSTEM		\
	-DAVIF_CODEC_DAV1D=SYSTEM	\
	-DAVIF_CODEC_RAV1E=SYSTEM	\
	-DAVIF_JPEG=SYSTEM		\
	-DAVIF_LIBXML2=SYSTEM		\
	-DAVIF_LIBYUV=SYSTEM		\
	-DAVIF_ZLIBPNG=SYSTEM		\
	-DAVIF_BUILD_APPS:BOOL=ON	\
	-DAVIF_BUILD_EXAMPLES:BOOL=ON	\
	-DAVIF_BUILD_GDK_PIXBUF:BOOL=ON
%cmake_build

%install
%cmake_install

%check
export PATH=%{buildroot}%{_bindir}:$PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH
avifdec --version
avifenc --version
%if %{with tests}
%ifarch ppc64le
skip="-E avifgainmaptest"
%endif
%ctest --parallel 1 --timeout 60 --verbose $skip
%endif

%ldconfig_scriptlets -n %{lib_name}

%files -n %{lib_name}
%license LICENSE
%{_libdir}/libavif.so.%{lib_soversion}*

%files devel
%license LICENSE
%{_libdir}/libavif.so
%{_includedir}/avif/
%{_libdir}/cmake/libavif/
%{_libdir}/pkgconfig/libavif.pc

%files -n avif-tools
%doc CHANGELOG.md README.md SECURITY.md
%license LICENSE
%{_bindir}/avifdec
%{_bindir}/avifenc
%{_bindir}/avifgainmaputil
%if %{with man_pages}
%{_mandir}/man1/avifdec.1%{?ext_man}
%{_mandir}/man1/avifenc.1%{?ext_man}
%endif

%files -n gdk-pixbuf-loader-libavif
%license LICENSE
%{_libdir}/gdk-pixbuf-2.0/*/loaders/libpixbufloader-avif.so
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/avif.thumbnailer

%changelog
* Fri May  9 2025 munix9@googlemail.com
- update to 1.3.0:
  * Add grayscale conversions in avifImageRGBToYUV and avifImageYUVToRGB.
  * Add avifRGBFormatIsGray to check whether an avifRGBFormat is gray.
  * Reject the conversion in avifenc from non-monochrome/monochrome to
    monochrome/non-monochrome when an ICC profile is present and not explicitly
    discarded.
  * Forbid encoding with AVIF_MATRIX_COEFFICIENTS_IDENTITY and
    AVIF_PIXEL_FORMAT_YUV400 to be AV1 spec compatible.
  * Do not go through RGB when reading/writing a grayscale PNG/JPG images in
    avifenc/avifdec
  * Ignore tmap items not present in grpl box
  * Assume any id is present in only one altr group as per spec.
  * avifpng.c: support ImageMagick app1 exif text data
  * avifjpeg.c: check for uint32_t overflow before add
  * Update googletest.cmd/LocalGTest.cmake: v1.16.0
  * Update libjpeg.cmd/LocalJpeg.cmake: 3.1.0
  * Update libsharpyuv: v1.5.0
  * Update libxml2.cmd/LocalLibXml2.cmake: v2.14.0
  * Update libyuv.cmd/LocalLibyuv.cmake: 4db2af62d (1909)
  * Update LocalRav1e.cmake: cargo-c v0.10.12
  * Update zlibpng.cmd: libpng 1.6.47
  * Fix wrong Exif orientation set in JPEG or PNG output by avifdec when the input
    AVIF file has an ImageRotation property with angle set to 1 or 3, has no
    ImageMirror property, and carries an Exif chunk. Note that Exif orientation is
    usually ignored in PNG files, so this mainly impacts JPEG files.
  * Encoder: fix ispe property for tmap with grid.
  * Decoder: check the ispe property of tmap items.
  * Allow lowercase GUIDs in XMP when reading JPEG files.
  * Update aom.cmd/LocalAom.cmake: v3.12.1
  * Change avifenc to start in automatic tiling mode.
  * Always forward Unspecified (2) CICP color primaries, transfer characteristics,
    and matrix coefficients to the AV1 encoder. Rely on the 'colr' box instead.
  * Declare *RowBytes as size_t in avifImageRGBToYUV()
  * Check ftell returned value in avifjpeg.c
  * Add integer overflow checks to makeRoom.
  * LocalJpeg.cmake: Support multi-config generators.
- Remove 'Group:' tags.
* Mon Apr 28 2025 munix9@googlemail.com
- Disable tests due to restrictions in Factory/ring1.
* Thu Apr 24 2025 munix9@googlemail.com
- Temporary deactivation of the generation of manual pages
  with pandoc due to restrictions in Factory/ring1.
  (https://build.opensuse.org/request/show/1272161#comment-2136811)
* Thu Apr 17 2025 munix9@googlemail.com
- update to 1.2.1:
  * Added since 1.2.0
  - Add support for outputting all frames of an image sequence in avifdec.
  - avifdec --index all sequence.avif out.png creates files named
  - out-xxxxxxxxxx.png where xxxxxxxxxx are the zero-padded frame indices.
  * Changed since 1.2.0
  - Fix local libargparse dependency patch step on macOS 10.15 and earlier.
  - Patch local libyuv dependency for compatibility with gcc 10.
  - Use stricter C99 syntax to avoid related compilation issues.
  - Update svt.cmd/svt.sh/LocalSvt.cmake to v3.0.1.
- update to 1.2.0:
  * Added since 1.1.1
  - Turn on the gain map API. Remove the AVIF_ENABLE_EXPERIMENTAL_GAIN_MAP CMake
    flag.
  - Allow YCgCo_Re and YCgCo_Ro encoding/decoding and update the enum values to
    the latest CICP specification. Remove the AVIF_ENABLE_EXPERIMENTAL_YCGCO_R
    CMake flag.
  - Add the properties and numProperties fields to avifImage. They are filled by
    the avifDecoder instance with the properties unrecognized by libavif. They are
    written by the avifEncoder.
  - Add avif(Un)SignedFraction structs and avifDoubleTo(Un)SignedFraction
    utility functions.
  - Add 'avifgainmaputil' command line tool to installed apps.
  - Add avifCropRectRequiresUpsampling().
  - Add experimental support for PixelInformationProperty syntax from HEIF 3rd Ed.
    Amd2 behind the compilation flag AVIF_ENABLE_EXPERIMENTAL_EXTENDED_PIXI.
  - Add experimental Sample Transform recipe
    BIT_DEPTH_EXTENSION_12B_8B_OVERLAP_4B.
  * Changed since 1.1.1
  - avifenc: Allow large images to be encoded.
  - Fix empty CMAKE_CXX_FLAGS_RELEASE if -DAVIF_CODEC_AOM=LOCAL -DAVIF_LIBYUV=OFF
    is specified. #2365.
  - Rename AVIF_ENABLE_EXPERIMENTAL_METAV1 to AVIF_ENABLE_EXPERIMENTAL_MINI and
    update the experimental reduced header feature to the latest specification
    draft. Rename AVIF_HEADER_REDUCED to AVIF_HEADER_MINI.
  - Update the experimental Sample Transform feature behind the
    AVIF_ENABLE_EXPERIMENTAL_SAMPLE_TRANSFORM CMake flag to the latest
    specification draft.
  - Ignore gain maps with unsupported metadata. Handle gain maps with
    writer_version > 0 correctly.
  - Simplify gain map API: remove the enableParsingGainMapMetadata setting, now
    gain map metadata is always parsed if present and if this feature is compiled
    in. Replace enableDecodingGainMap and ignoreColorAndAlpha with a bit field to
    choose image content to decode. Remove gainMapPresent: users can check if
    decoder->image->gainMap != NULL instead. Remove avifGainMapMetadata and
    avifGainMapMetadataDouble structs.
  - Write an empty HandlerBox name field instead of "libavif" (saves 7 bytes).
  - Check for FileTypeBox precedence in avifParse().
  - Do not write an alternative group with the same ID as an item.
  - Update aom.cmd/LocalAom.cmake: v3.12.0. The new codec-specific option tune=iq
    (image quality) is added in libaom v3.12.0.
  - Update parseAV2SequenceHeader() and avm.cmd: research-v9.0.0
  - Update dav1d.cmd/dav1d_android.sh/LocalDav1d.cmake: 1.5.1
  - Update libjpeg.cmd/LocalJpeg.cmake: v3.0.4
  - Update libxml2.cmd/LocalLibXml2.cmake: v2.13.5
  - Update libyuv.cmd: ccdf87034 (1903)
  - Update svt.cmd/svt.sh/LocalSvt.cmake to v3.0.0. When available, use
    EbSvtAv1EncConfiguration::lossless and ::level_of_parallelism in libavif.
  - Remove AVIF_ENABLE_GTEST CMake option. It's now implied by
    AVIF_GTEST=LOCAL/SYSTEM.
  - Deprecate avifEncoder's minQuantizer, maxQuantizer, minQuantizerAlpha,
    and maxQuantizerAlpha fields. quality and qualityAlpha should be used
    instead. Deprecate avifenc's --min, --max, --minalpha and --maxalpha
    flags. -q or --qcolor and --qalpha should be used instead.
  - For dependencies, the deprecated way of setting AVIF_LOCAL_* to ON is
    removed. Dependency options can now only be set to OFF/LOCAL/SYSTEM.
  - Change the default quality for alpha to be the same as the quality for color.
  - Allow decoding subsampled images with odd Clean Aperture dimensions or offsets.
  - Deprecate avifCropRectConvertCleanApertureBox() and
    avifCleanApertureBoxConvertCropRect(). Replace them with
    avifCropRectFromCleanApertureBox() and avifCleanApertureBoxFromCropRect().
  - Write descriptive properties before transformative properties.
  - Reject non-essential transformative properties.
  - Treat avifenc --stdin as a regular positional file path argument.
  - Update man pages based on avifenc/dec's --help message.
  - android_jni: Support 16kb page size
  - android_jni: Set threads to 2 instead of CPU count
  - Fix overflows when dealing with alpha during YUV/RGB conversions and in
    avifRGBImageAllocatePixels().
  - Make avifEncoder.headerFormat a flag combination for future features.
  - Rename AVIF_HEADER_FULL to AVIF_HEADER_DEFAULT. Deprecate AVIF_HEADER_FULL.
  - Fix decoding image sequences with non video tracks (such as audio or subtitles).
  - Fix type checking of auxiliary tracks: previously any auxiliary track was
    assumed to be alpha, even if it was a different type. If the aux type is absent,
    it is assumed to be alpha.
- Add libargparse-ee74d1b53bd680748af14e737378de57e2a0a954.tar.gz
- Add %%check/tests
- Add man pages
* Tue Sep 10 2024 Carsten Ziepke <kieltux@gmail.com>
- Enable building with aom and libyuv for Leap
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * In avif.h, change "AVIF_API AVIF_NODISCARD" back to
    "AVIF_NODISCARD AVIF_API" to fix clang-cl and MSVC compilation
    errors in the shared library build on Windows.
  * Fix -DAVIF_GTEST=SYSTEM
  * Fix infe_type and codec_config_type wrongly read as byte-
    aligned fields in the
  * experimental feature AVIF_ENABLE_EXPERIMENTAL_METAV1.
  * When building aom as a local dependency, runtime CPU
    detection (`CONFIG_RUNTIME_CPU_DETECT`) is now always `ON`;
  * Fix CMake config shared library leaks
  * Update gain map metadata to current ISO 21496-1 draft.
  * cmake: Only search for ASM_NASM language on x86_64 platforms.
  * Fix "No known features for CXX compiler" CMake error.
  * Fix aom link flags so that transitive library link flags are
    included when aom is a static library
  * Fix out-of-order 'dimg' grid associations
  * Report files with an item used in multiple 'dimg' boxes with
  * AVIF_RESULT_NOT_IMPLEMENTED instead of
    AVIF_RESULT_INVALID_IMAGE_GRID.
  * Add experimental API for reading and writing gain maps in
    AVIF files.
  * If enabled at compile time, add `gainMap` field to
    `avifImage`,
  * add `qualityGainMap` field to `avifEncoder`, add
    `gainMapPresent`, `enableDecodingGainMap`,
    `enableParsingGainMapMetadata` and `ignoreColorAndAlpha` to
    `avifDecoder`.
  * Utility functions for working with gain maps are also added.
  * Gain maps allow readers that support them to display HDR
    images that look good on both HDR and SDR displays.
  * Add experimental support for converting jpeg files with gain
    maps to AVIF files with gain maps. Requires libxml2, and the
    AVIF_ENABLE_EXPERIMENTAL_GAIN_MAP compilation flag.
  * Add a --qgain-map flag to control the gain map quality in
    avifenc.
  * Add the headerFormat member of new type avifHeaderFormat to
    avifEncoder.
  * Add experimental API for reading and writing "mif3"-branded
    AVIF files behind the compilation flag
    AVIF_ENABLE_EXPERIMENTAL_METAV1.
  * Implement avifImageScale() fallback when libyuv is not
    available.
  * Partial import of libyuv to third_party/libyuv (new LICENSE).
  * Add avifenc flag suffixes ":update" and ":u". Quality-
    relative, tiling-relative and codec-specific flags can now be
    positional, relative to input files.
  * Add experimental support for layered AVIF encoding in
    avifenc.
  * Use the --layered flag to enable layered AVIF encoding.
  * Layered AVIF has multiple layers, which works like frame of
    animated AVIF, and layers can be rendered in progressive
    manner on supported viewers
  * Only aom supports layered AVIF encoding at the time of
    writing.
  * Add --scaling-mode flag to set scaling mode of each layer.
  * This part of AV1 encoder is not as thoroughly tested, so
    there are higher possibility encoder may crash when given certain
    configuration or input.
  * Add imageSequenceTrackPresent flag to the avifDecoder struct.
  * avifImageScale() function was made part of the public ABI.
  * Add avif_cxx.h as a C++ header with basic functionality.
  * Add enum aliases AVIF_COLOR_PRIMARIES_SRGB,
    AVIF_COLOR_PRIMARIES_BT2100,
  * AVIF_COLOR_PRIMARIES_DCI_P3,
    AVIF_TRANSFER_CHARACTERISTICS_PQ.
  * Add avifResult enum entry AVIF_RESULT_INTERNAL_ERROR.
  * Require libyuv by default (but it can still be disabled with
  * -DAVIF_LIBYUV=OFF).
  * Add avifdec --icc flag to override the output color profile.
  * Add experimental API for reading and writing 16-bit AVIF
    files behind the
  * compilation flag AVIF_ENABLE_EXPERIMENTAL_SAMPLE_TRANSFORM.
  * Add AVIF_CHROMA_SAMPLE_POSITION_RESERVED to
    avifChromaSamplePosition enum.
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.4:
  * AVIF_ENABLE_WERROR is set to OFF by default.
  * Fix wrong alpha plane deallocation when decoded tile pixel
    format does not match reconstructed output image pixel format
  * Fix identical chunk skipping optimization when writing
    animation data
  * Fix ID selection for artificial grid alpha item when decoding
    a grid of tiles which each have an associated auxiliary alpha
    image item (https://crbug.com/oss-fuzz/65657).
* Thu Dec 21 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.0.3:
  * Rewrite the fix for memory errors fixed in 1.0.2
  * CVE-2023-6704: Fix use-after-free errors (boo#1218303)
  * src/reformat.c: Allocate the threadData array directly
* Tue Nov 28 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.0.2:
  * Update avifCropRectConvertCleanApertureBox() to the revised
    requirements in ISO/IEC 23000-22:2019/Amd. 2:2021 Section
    7.3.6.7.
  * CVE-2023-6350: Out of bounds memory to alphaItemIndices (boo#1217614)
  * CVE-2023-6351: use-after-free in colorProperties (boo#1217615)
- drop fix-gdkpixbuf.patch
* Tue Aug 29 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.0.0:
  * Incompatible changes:
    + The clli member was added to the avifImage struct.
    + The repetitionCount member was added to the avifEncoder and avifDecoder
    structs.
    + The quality and qualityAlpha members were added to the avifEncoder struct.
    + Check that functions returning pointers do not return NULL before accessing
    those pointers.
    + Check the return value of avifEncoderSetCodecSpecificOption().
    + The maxThreads member was added to the avifRGBImage struct.
    + Check the return value of avifRGBImageAllocatePixels(), avifRWDataRealloc(),
    avifRWDataSet(), avifImageSetProfileICC(), avifImageSetMetadataExif() and
    avifImageSetMetadataXMP().
    + The meaning of the keyframeInterval member of avifEncoder struct has changed
    slightly. When set to a value of "n",
    Before: It forces a keyframe on every nth frame.
    After: Any set of "n" consecutive frame will have at least one keyframe
    (every nth frame may or may not be a keyframe).
  * Added:
    + Add clli metadata read and write support
    + Add repetitionCount member to avifEncoder and avifDecoder structs to specify
    the number of repetitions for animated image sequences.
    + Add quality and qualityAlpha to avifEncoder. Note: minQuantizer,
    maxQuantizer, minQuantizerAlpha, and maxQuantizerAlpha are deprecated. Code
    should be updated to set quality (and qualityAlpha if applicable) and leave
    minQuantizer, maxQuantizer, minQuantizerAlpha, and maxQuantizerAlpha
    initialized to the default values.
    + The --target-size flag in avifenc was added to adapt the quality so that the
    output file size is as close to the given number of bytes as possible.
    + Add the public API function avifImageIsOpaque() in avif.h.
    + Add the public API functions avifImagePlane(), avifImagePlaneRowBytes(),
    avifImagePlaneWidth(), and avifImagePlaneHeight() in avif.h.
    + Add API for multi-threaded YUV to RGB color conversion.
    + Allow lossless 4:0:0 on grayscale input.
    + Add avifenc --no-overwrite flag to avoid overwriting output file.
    + Add avifenc --clli flag to set clli.
    + Add support for all transfer functions when using libsharpyuv.
  * Changed:
    + Exif and XMP metadata is exported to PNG and JPEG files by default,
    except XMP payloads larger than 65502 bytes in JPEG.
    + The --grid flag in avifenc can be used for images that are not evenly divided
    into cells.
    + Change the encoder to write the boxes within the "stbl" box in the order of
    stsd, stts, stsc, stsz, stco, stss.
    + avifImageRGBToYUV() and avifImageYUVToRGB() handle avifImage bit depths 8, 10,
    12 and now also 16. Files read by apps/shared/ can output 16-bit avifImage
    instances.
    + avifImageCreate(), avifImageCreateEmpty(), avifEncoderCreate() and other
    internal functions now return NULL if a memory allocation failed.
    + avifEncoderSetCodecSpecificOption() now returns avifResult instead of void to
    report memory allocation failures.
- Add fix-gdkpixbuf.patch.
* Sun May  7 2023 Arjen de Korte <suse+build@de-korte.org>
- Add BuildRequires pkgconfig(libwebp) to enable libsharpyuv
* Mon Nov 14 2022 ecsos <ecsos@opensuse.org>
- Update to version 0.11.1:
  * Changed:
  - avifincrtest_helpers: Cast 64-bit offset to size_t
  - avifmetadatatest: don't include avif/internal.h
  - avifrgbtoyuvtest: skip if no libsharpyuv
  - Disable tests that may fail if the codec is not aom (#1176)
* Thu Oct 27 2022 Cristian Rodríguez <crrodriguez@opensuse.org>
- Remove unused BuildRequires on nasm
- Remove indirect/incorrect Buildrequires on zlib
- add direct glib Buildrequires
* Sat Oct 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.11.0:
  * There are incompatible ABI changes in this release. The
    alphaRange member was removed from the avifImage struct. The
    chromaDownsampling and avoidLibYUV members were added to the
    avifRGBImage struct. The imageDimensionLimit member was added
    to the avifDecoder struct. avifImageCopy() and
    avifImageAllocatePlanes() signatures changed. It is necessary
    to recompile your code. Also check the return values of
    avifImageCopy() and avifImageAllocatePlanes().
  * Added:
  - Add man pages for avifenc and avifdec
  - Add the avifChannelIndex type alias for enum avifChannelIndex
  - Add avifChromaDownsampling enum
  - Add chromaDownsampling field to avifRGBImage struct
  - Add support for AVIF_RGB_FORMAT_RGB_565
  - Add imageDimensionLimit field to avifDecoder struct
  - Add autoTiling field to avifEncoder struct
  - Add new avifResult codes AVIF_RESULT_CANNOT_CHANGE_SETTING
    and AVIF_RESULT_INCOMPATIBLE_IMAGE
  - Add new enum constants AVIF_PIXEL_FORMAT_COUNT and
    AVIF_RGB_FORMAT_COUNT
  - avifdec: Add --dimension-limit, which specifies the image
    dimension limit (width or height) that should be tolerated
  - avifenc: Add --sharpyuv, which enables "sharp" RGB to YUV420
    conversion, which reduces artifacts caused by 420 chroma
    downsampling. Needs libsharpyuv (part of the libwebp
    repository) at compile time.
  - avifenc: Add --ignore-exif and --ignore-xmp flags.
  - avifenc: Add --autotiling, which sets --tilerowslog2 and
  - -tilecolslog2 automatically.
  - avifenc: Input Exif orientation is converted to irot/imir by
    default.
  * Changed:
  - Fix memory leaks of metadata on avifenc exit
  - Update the handling of 'lsel' and progressive decoding to
    AVIF spec v1.1.0
  - Treat an absent lsel and layer_id == 0xFFFF equivalently for
    backward compatibility with earlier drafts of AVIF spec
    v1.1.0
  - Set libavif's own default value of cfg.rc_end_usage for
    libaom
  - Set the libaom-specific option -a tune=ssim by default
  - Bump cmake_minimum_required from 3.5 to 3.13
  - Fix https://crbug.com/oss-fuzz/48135
  - Use several new libyuv functions in reformat_libyuv.c
  - Fix SVT-AV1's issue 1957 related to uninitialized variables
    crashing the encoder
  - Update aom.cmd: v3.5.0
  - Update rav1e.cmd: v0.5.1
  - Update svt.cmd/svt.sh: v1.2.1
  - Update libgav1.cmd: v0.18.0
  - Update libyuv.cmd: f9fda6e7 (version 1844)
  - avifImageCopy() and avifImageAllocatePlanes() now return
    avifResult instead of void to report invalid parameters or
    memory allocation failures.
  - avifImageRGBToYUV() now uses libyuv fast paths by default. It
    may slightly change conversion results. The old behavior can
    be restored by setting avifRGBImage::chromaDownsampling to
    AVIF_CHROMA_DOWNSAMPLING_BEST_QUALITY and
    avifRGBImage::avoidLibYUV to AVIF_TRUE.
  - avifRGBImage::chromaUpsampling now only applies to
    conversions that need upsampling chroma from 4:2:0 or 4:2:2
    and has no impact on the use of libyuv.
  - Set avifRGBImage::avoidLibYUV accordingly to control the use
    of libyuv.
  - avifenc: Set the YUV format to 4:0:0 for grayscale PNGs
  - Support updating encoder settings and codec-specific options
    during encoding
  - Disable AVIF_STRICT_CLAP_VALID and AVIF_STRICT_PIXI_REQUIRED
    in the JNI wrapper
  - avifdec: Return proper exit code in "info" mode
  - In avifenc and avifdec, treat all arguments that start with
    '-' as options
  - Exif and XMP metadata is imported from PNG and JPEG files.
  - avifImageSetMetadataExif() parses the Exif metadata and
    converts any Exif orientation found into transformFlags, irot
    and imir values.
  - Write 'auxi' box for animated images with alpha channel
  - Write 'auxv' as handler_type for alpha channel track
  - Use PNG_COLOR_TYPE_GRAY for 8-bit grayscale output
  - Replace repeated subtraction by modulo in calcGCD
  - Change avifImageCreate to take uint32_t instead of int
    parameters
  - When writing an image sequence, check if it's safe to cast
    width and height to uint16_t
  - Allow clamped grid cells in avifEncoderAddImageGrid()
  * Removed:
  - alphaRange field was removed from the avifImage struct. It it
    presumed that alpha plane is always full range.
  - The avifCodecConfigurationBox struct becomes a private type
    for libavif internal use
- Bump lib_soversion global (also in baselibs.conf) to 15 following
  upstream change.
- Use ldconfig_scriptlets for post(un) handling.
* Sat Jul 30 2022 Callum Farmer <gmbr3@opensuse.org>
- Enable libyuv on TW
* Sun Apr 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.10.1:
  * tests/docker/build.sh: Build SVT-AV1 using cmake and ninja directly
  * Fix a Visual Studio 2017 compiler warning in src\reformat.c: warning C4204:
    nonstandard extension used: non-constant aggregate initializer
  * Fix the help message of avifdec: --index takes a value
* Fri Apr  8 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.10.0
  * See https://github.com/AOMediaCodec/libavif/blob/v0.10.0/CHANGELOG.md
    for a complete changelog or check the CHANGELOG.md in the doc directory.
* Sat Dec 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Disable libaom and use rav1e by default
  * As PHP 8.1 has AVIF support, use rav1e by default as it is more
    secure being written in Rust.
* Thu Oct 21 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.9.3
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.3/CHANGELOG.md
    for a complete changelog.
* Thu Jun 24 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.9.2
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.2/CHANGELOG.md
    for a complete changelog.
* Thu May 20 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.9.1
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.1/CHANGELOG.md
    for a complete changelog.
* Tue Apr 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add baselibs.conf: produce libavif10-32bit as a new dependency to
  libgd3-32bit (support avif in libgd).
* Mon Mar 15 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.9.0
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.0/CHANGELOG.md
    for a complete changelog.
* Wed Jan 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Build the gdk-pixbuf module: Add pkgconfig(gdk-pixbuf-2.0)
  BuildRequires and pass DAVIF_BUILD_GDK_PIXBUF=ON to cmake.
  Package the resulting loader in a new sub package.
- Use cmake_build macro.
* Wed Dec  9 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.8.4
  * See https://github.com/AOMediaCodec/libavif/blob/v0.8.4/CHANGELOG.md
    for a complete changelog.
* Thu Oct 15 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.8.2
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
* Mon Aug 17 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.8.1
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
- Enabled AOM support (default)
* Tue Jul 21 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.8.0
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
* Tue May  5 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.7.3
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
  * Removed e4e5d752ece581d6ef9fbb8bab0ab2edfde13fc5.patch
  * Removed ebb29b37711c749681278f8b778f0e6c031c4ca2.patch
  * Removed e7dcc74b5529da209266020852a72b554461e538.patch
* Mon May  4 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.7.2
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
  * Added e4e5d752ece581d6ef9fbb8bab0ab2edfde13fc5.patch
  * Added ebb29b37711c749681278f8b778f0e6c031c4ca2.patch
  * Added e7dcc74b5529da209266020852a72b554461e538.patch
* Thu Apr 23 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 0.7.1
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
- Add BR on libjpeg8-devel
* Wed Mar 11 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.2
  https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
* Wed Mar 11 2020 Andreas Schneider <asn@cryptomilk.org>
- If we want to build with aom, require version >= 1.1.0
- Removed cbcf62c2200be83b85b48059c819ae708216ccec.patch
* Wed Mar  4 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.5.7
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.7
* Sun Feb 16 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.5.5
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.5
- Rename libavif-tools to avif-tools
  This fixes an rpmlint warning
* Wed Dec 11 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.5.3
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.3
* Sun Nov 24 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 0.5.2
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.2
* Fri Nov 22 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 0.5.1
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.1
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.0
* Wed Nov 20 2019 Marcus Rueckert <mrueckert@suse.de>
- support building with libaom 1.0.0
  https://github.com/cryptomilk/libavif/commit/cbcf62c2200be83b85b48059c819ae708216ccec.patch
* Wed Nov 20 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 0.4.8
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.4.8
- drop libs.patch
* Mon Nov 18 2019 Marcus Rueckert <mrueckert@suse.de>
- initial package
